@@ -54,6 +54,10 @@ be less certain about them, but match more.
 
 =back
 
+=head1 REPOSITORY
+
+L<https://github.com/brianary/Lingua-EN-Nickname>
+
 =head1 AUTHOR
 
 Brian Lalonde, E<lt>brian@webcoder.infoE<gt>
@@ -70,7 +74,7 @@ use strict;
 use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 use vars qw(%root %multi %match %akin);
 
-$VERSION=     '1.34';
+$VERSION=     '1.35';
 @ISA=         qw(Exporter);
 @EXPORT=      qw(nickname_eq nickroot);
 @EXPORT_OK=   qw(nickmatch nickfollow);
